import { ApolloQueryResult } from "@apollo/client/core";
import type { CustomHeaders, GuestAvailablePaymentMethodsQuery } from "@vue-storefront/magento-types";
import { Context } from "../../types/context";
/**
 * Get available payment methods for the received guest cart.
 * To get available customer payment methods use {@link https://docs.vuestorefront.io/integrations/magento/api/magento-api/getAvailableCustomerPaymentMethods | getAvailableCustomerPaymentMethods }.
 *
 * @example
 * Simple usage:
 * ```ts
 * import { sdk } from '~/sdk.config.ts';
 *
 * // fetch guest available payment methods
 * const result = await sdk.magento.getAvailablePaymentMethods({
 *  cartId: 'masked-cart-id'
 * });
 *
 * // example result
 * {
 *   "data": {
 *     "cart": {
 *       "__typename": "Cart",
 *       "available_payment_methods": [
 *         {
 *           "__typename": "AvailablePaymentMethod",
 *           "code": "checkmo",
 *           "title": "Check / Money order"
 *         }
 *       ]
 *     }
 *   },
 *   "loading": false,
 *   "networkStatus": 7
 * }
 * ```
 */
export declare function getAvailablePaymentMethods(context: Context, cartId: string, customHeaders?: CustomHeaders): Promise<ApolloQueryResult<GuestAvailablePaymentMethodsQuery>>;
//# sourceMappingURL=index.d.ts.map