import { ApolloQueryResult } from "@apollo/client/core";
import type { CustomHeaders } from "@vue-storefront/magento-types";
import { CartQuery } from "@vue-storefront/magento-types";
import { Context } from "../../types/context";
/**
 * Resolve cart total quantity
 * This method is optimized to fetch only total quantity of the cart and not the whole cart object.
 * Do not use `cart` query inf you want to fetch only total quantity of the cart.
 *
 * @example
 * Simple usage:
 * ```ts
 * import { sdk } from '~/sdk.config.ts';
 *
 * // fetch total quantity of the cart
 * const { data } await sdk.magento.cartTotalQty({cartId: 'some_cart_id' });
 *
 * // total quantity of the cart available in data.cart.total_quantity
 * ```
 */
export declare function cartTotalQty(context: Context, cartId: string, customHeaders?: CustomHeaders): Promise<ApolloQueryResult<CartQuery>>;
//# sourceMappingURL=index.d.ts.map